@@ -20,7 +20,8 @@ basic html templates and (buggy - patches welcome) pass through login.
 Once you're done running this script, add a user with the
 script/myapp_auth_admin.pl command (run myapp_auth_admin.pl -help for
 instructions), and then add some code to one of your controllers.  For
-example to require application wide authentication add the following to your Controller::Root :
+example to require application wide authentication add the following
+to your Controller::Root :
 
 
 
@@ -45,6 +46,6 @@ Catalyst::Helper::AuthDBIC::make_model();
 Catalyst::Helper::AuthDBIC::mk_auth_controller() if $credential eq 'password';
 Catalyst::Helper::AuthDBIC::add_plugins();
 Catalyst::Helper::AuthDBIC::add_config($credential);
-Catalyst::Helper::AuthDBIC::write_templates();
+Catalyst::Helper::AuthDBIC::write_templates() if $credential eq 'password';
 Catalyst::Helper::AuthDBIC::update_makefile();
 Catalyst::Helper::AuthDBIC::add_user_helper();
